@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.17 2003/11/19 11:33:00 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.18 2003/11/21 21:03:31 fuyu Exp $
  */
 
 #include "config.h"
@@ -42,6 +42,29 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#if ENABLE_REGEXP
+# if HAVE_ONIGURUMA
+#  if HAVE_ONIG_ONIGPOSIX_H
+#    include <onig/onigposix.h>
+#  elif HAVE_ONIGPOSIX_H
+#    include <onigposix.h>
+#  else
+#    error "Use of oniguruma without onig/onigposix.h header isn't considered."
+#  endif
+# else
+#  if HAVE_POSIX_REGEX
+#    if HAVE_SYS_TYPES_H
+#      include <sys/types.h>
+#    endif
+#    if HAVE_REGEX_H
+#      include <regex.h>
+#    else
+#      warning "I don't know suitable header file of your posix regex library."
+#    endif
+#  endif
+# endif
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
