@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: board_properties.c,v 1.4 2003/06/12 04:14:43 fuyu Exp $
+ * $Id: board_properties.c,v 1.5 2003/11/22 19:17:16 fuyu Exp $
  */
 
 #include "config.h"
@@ -48,6 +48,10 @@ typedef struct _DialogStates
   OchushaBulletinBoard *board;
   BulletinBoardGUIInfo *info;
 
+  GtkToggleButton *use_ochusha_default_button;
+  GtkToggleButton *show_mailto_button;
+  GtkToggleButton *hide_mailto_button;
+
   ThreadlistFilterSetting *setting;
   GtkToggleButton *use_as_default_button;
   GtkToggleButton *enable_filter_button;
@@ -62,6 +66,9 @@ typedef struct _DialogStates
 static GtkWidget *build_board_info_frame(OchushaApplication *application,
 					 OchushaBulletinBoard *board,
 					 DialogStates *states);
+static GtkWidget *build_thread_view_setting_frame(OchushaApplication *application,
+						  OchushaBulletinBoard *board,
+						  DialogStates *states);
 static GtkWidget *build_filter_setting_frame(OchushaApplication *application,
 					     OchushaBulletinBoard *board,
 					     DialogStates *states);
@@ -165,6 +172,25 @@ open_board_properties(OchushaApplication *application,
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), frame);
 
+  frame = build_thread_view_setting_frame(application, board, states);
+  gtk_widget_show(frame);
+  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), frame);
+
+  switch (info->show_mailto_mode)
+    {
+    case THREAD_VIEW_MAILTO_MODE_DEFAULT:
+      gtk_toggle_button_set_active(states->use_ochusha_default_button, TRUE);
+      break;
+
+    case THREAD_VIEW_MAILTO_MODE_SHOW:
+      gtk_toggle_button_set_active(states->show_mailto_button, TRUE);
+      break;
+
+    case THREAD_VIEW_MAILTO_MODE_HIDE:
+      gtk_toggle_button_set_active(states->hide_mailto_button, TRUE);
+      break;
+    }
+
   frame = build_filter_setting_frame(application, board, states);
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), frame);
@@ -240,6 +266,19 @@ apply_current_states(GtkWidget *dialog, DialogStates *states)
   states->info->enable_filter
     = gtk_toggle_button_get_active(states->enable_filter_button);
 
+  if (gtk_toggle_button_get_active(states->show_mailto_button))
+    {
+      states->info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_SHOW;
+    }
+  else if (gtk_toggle_button_get_active(states->hide_mailto_button))
+    {
+      states->info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_HIDE;
+    }
+  else
+    {
+      states->info->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_DEFAULT;
+    }
+
   if (gtk_toggle_button_get_active(states->use_as_default_button))
     {
       G_FREE(states->application->user_default_filter.rule);
@@ -361,6 +400,50 @@ build_board_info_frame(OchushaApplication *application,
 }
 
 
+static GtkWidget *
+build_thread_view_setting_frame(OchushaApplication *application,
+				OchushaBulletinBoard *board,
+				DialogStates *states)
+{
+  GtkWidget *tmp_widget;
+  GtkWidget *thread_frame = gtk_frame_new(_("Default Setting of Thread Views on This Board"));
+  GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
+
+  gtk_widget_show(hbox);
+  gtk_container_add(GTK_CONTAINER(thread_frame), hbox);
+
+  tmp_widget = gtk_label_new(_("Show mailto literally:"));
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), tmp_widget, FALSE, FALSE, 5);
+
+  tmp_widget
+    = gtk_radio_button_new_with_label(NULL, _("Use Ochusha's Default"));
+  g_signal_connect(G_OBJECT(tmp_widget), "toggled",
+		   G_CALLBACK(button_toggled_cb), states);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), tmp_widget, FALSE, FALSE, 0);
+  states->use_ochusha_default_button = GTK_TOGGLE_BUTTON(tmp_widget);
+  
+  tmp_widget = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(states->use_ochusha_default_button), _("Show mailto"));
+  g_signal_connect(G_OBJECT(tmp_widget), "toggled",
+		   G_CALLBACK(button_toggled_cb), states);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), tmp_widget, FALSE, FALSE, 0);
+  states->show_mailto_button = GTK_TOGGLE_BUTTON(tmp_widget);
+
+  tmp_widget = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(states->use_ochusha_default_button), _("Hide mailto"));
+  g_signal_connect(G_OBJECT(tmp_widget), "toggled",
+		   G_CALLBACK(button_toggled_cb), states);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), tmp_widget, FALSE, FALSE, 0);
+  states->hide_mailto_button = GTK_TOGGLE_BUTTON(tmp_widget);
+
+  gtk_widget_show(hbox);
+
+  return thread_frame;
+}
+
+
 static GtkWidget *
 build_filter_setting_frame(OchushaApplication *application,
 			   OchushaBulletinBoard *board, DialogStates *states)
