@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.23 2003/11/22 19:17:16 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.26 2003/11/23 22:51:13 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,6 +40,7 @@
 #include "boardlist_view.h"
 #include "bulletin_board_ui.h"
 #include "paned_notebook.h"
+#include "response_editor.h"
 #include "text_search_window.h"
 #include "ugly_gtk2utils.h"
 
@@ -73,6 +74,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 
 
@@ -140,17 +142,18 @@ static void page_switched_cb(PanedNotebook *paned_notebook,
 			     GtkWidget *previous_page, GtkWidget *new_page,
 			     OchushaApplication *application);
 
-#if 0
 static void make_new_thread_button_cb(GtkWidget *widget,
 				      OchushaApplication *application);
-#endif
 static void open_board_properties_button_cb(GtkWidget *widget,
 					    OchushaApplication *application);
 static void refresh_board_button_cb(GtkWidget *widget,
 				    OchushaApplication *application);
 static void start_threadlist_search_button_cb(GtkWidget *widget,
 					      OchushaApplication *application);
-
+static void new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
+					  OchushaApplication *application);
+static GtkWidget *create_new_thread_dialog(OchushaApplication *application,
+					   OchushaBulletinBoard *board);
 
 
 /* Υå˰٤ǤⳫ(OchushaBulletinBoard *)Υꥹȡ*/
@@ -181,6 +184,7 @@ typedef struct _BoardCategoryGUIInfo
 
 
 static GQuark category_gui_info_id;
+static GQuark application_id;
 
 
 void
@@ -194,14 +198,32 @@ prepare_boardlist_ui_initialization(OchushaApplication *application)
 
   category_gui_info_id
     = g_quark_from_static_string("BoardlistUI::CategoryInfo");
+  application_id
+    = g_quark_from_static_string("BoardlistUI::Application");
 }
 
 
 static void
-open_view_cb(GtkWidget *selector, gpointer item, gboolean in_tab,
-	     PanedNotebook *paned_notebook)
+open_threadlist_view_cb(GtkWidget *selector, OchushaBulletinBoard *board,
+			gboolean in_tab, gboolean with_browser,
+			PanedNotebook *paned_notebook)
 {
-  paned_notebook_open_item_view(paned_notebook, item, in_tab);
+  if (!with_browser)
+    paned_notebook_open_item_view(paned_notebook, board, in_tab);
+  else
+    {
+      OchushaApplication *application
+	= g_object_get_qdata(G_OBJECT(selector), application_id);
+      if (application != NULL)
+	ochusha_open_url(application,
+			 ochusha_bulletin_board_get_base_url(board),
+			 in_tab, with_browser);
+#if 0	/* Թΰ */
+      else
+	fprintf(stderr, "open_threadlist_view_cb: %s\n",
+		ochusha_bulletin_board_get_base_url(board));
+#endif
+    }
 }
 
 
@@ -215,6 +237,8 @@ initialize_boardlist(OchushaApplication *application)
   board_list = NULL;
 
   application->boardlist_view = boardlist_view_new();
+  g_object_set_qdata(G_OBJECT(application->boardlist_view), application_id,
+		     application);
   g_signal_connect(G_OBJECT(application->boardlist_view), "category_expanded",
 		   G_CALLBACK(category_expanded_cb), application);
   g_signal_connect(G_OBJECT(application->boardlist_view), "category_collapsed",
@@ -247,8 +271,9 @@ initialize_boardlist(OchushaApplication *application)
   application->contents_window
     = paned_notebook_new_with_selector(application->boardlist_pane_style,
 				       scrolled_window);
-  g_signal_connect(G_OBJECT(application->boardlist_view), "open_view",
-		   G_CALLBACK(open_view_cb), application->contents_window);
+  g_signal_connect(G_OBJECT(application->boardlist_view),
+		   "open_threadlist_view", G_CALLBACK(open_threadlist_view_cb),
+		   application->contents_window);
   gtk_paned_set_position(GTK_PANED(application->contents_window),
 			 application->boardlist_width);
   paned_notebook_set_always_show_contents_pane(PANED_NOTEBOOK(application->contents_window),
@@ -260,7 +285,6 @@ initialize_boardlist(OchushaApplication *application)
 
   toolbar = paned_notebook_get_toolbar(PANED_NOTEBOOK(application->contents_window));
 
-#if 0
   gtk_toolbar_prepend_space(toolbar);
   gtk_toolbar_insert_stock(toolbar, GTK_STOCK_NEW,
 			   _("Make a new thread at the current board"),
@@ -268,7 +292,6 @@ initialize_boardlist(OchushaApplication *application)
 			   GTK_SIGNAL_FUNC(make_new_thread_button_cb),
 			   application,
 			   0);
-#endif
 
   gtk_toolbar_prepend_space(toolbar);
   gtk_toolbar_insert_stock(toolbar, GTK_STOCK_PROPERTIES,
@@ -424,12 +447,13 @@ finalize_boardlist(OchushaApplication *application)
 }
 
 
-#if 0
 void
 make_new_thread(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
   OchushaBulletinBoard *board;
+  BulletinBoardGUIInfo *info;
+  GtkWidget *new_thread_dialog;
 
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
@@ -440,11 +464,32 @@ make_new_thread(OchushaApplication *application)
   if (board == NULL)
     return;
 
-  /*
-   * TODO: 빽ݤʤΤǺ٤ˤ褦
-   */
+  if (!ochusha_bulletin_board_is_new_thread_supported(board))
+    {
+      ochusha_open_url(application,
+		       ochusha_bulletin_board_get_base_url(board),
+		       FALSE, TRUE);
+      return;
+    }
+
+  info = ensure_bulletin_board_info(board, application);
+
+  if (info->new_thread_dialog == NULL)
+    {
+      new_thread_dialog = create_new_thread_dialog(application, board);
+      info->new_thread_dialog = new_thread_dialog;
+    }
+  else
+    return;
+
+  g_signal_connect(G_OBJECT(new_thread_dialog), "response",
+		   G_CALLBACK(new_thread_dialog_response_cb), application);
+  g_signal_connect(G_OBJECT(new_thread_dialog), "destroy",
+		   G_CALLBACK(gtk_widget_destroyed),
+		   &info->new_thread_dialog);
+
+  gtk_widget_show_all(new_thread_dialog);
 }
-#endif
 
 
 void
@@ -1351,13 +1396,11 @@ setup_boardlist(OchushaApplication *application)
 }
 
 
-#if 0
 static void
 make_new_thread_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
   make_new_thread(application);
 }
-#endif
 
 
 static void
@@ -1382,3 +1425,203 @@ start_threadlist_search_button_cb(GtkWidget *widget,
   start_current_threadlist_search(application);
 }
 
+
+static void
+new_thread_dialog_response_cb(GtkWidget *dialog, gint response_id,
+			      OchushaApplication *application)
+{
+  OchushaBulletinBoard *board = g_object_get_data(G_OBJECT(dialog), "board");
+  gboolean result;
+
+  if (response_id == GTK_RESPONSE_OK)
+    {
+      ResponseEditor *editor = g_object_get_data(G_OBJECT(dialog), "editor");
+      GtkEntry *title_entry = g_object_get_data(G_OBJECT(dialog), "title");
+      const gchar *title = gtk_entry_get_text(title_entry);
+      gchar *message;
+      OchushaBBSResponse response;
+
+      response.name = response_editor_get_name(editor);
+      response.mailto = response_editor_get_mail(editor);
+      message = response_editor_get_response(editor);
+      response.content = message;
+
+      if (title != NULL && *title != '\0'
+	  && message != NULL && *message != '\0')
+	{
+	  result = ochusha_bulletin_board_create_new_thread(board,
+						&application->config,
+						title, &response);
+	  g_free(message);
+	  if (result)
+	    {
+	      BulletinBoardGUIInfo *board_info
+		= ensure_bulletin_board_info(board, application);
+
+	      if (board_info->last_name == NULL
+		  || strcmp(board_info->last_name, response.name) != 0)
+		{
+		  if (board_info->last_name != NULL)
+		    G_FREE(board_info->last_name);
+		  board_info->last_name = G_STRDUP(response.name);
+		}
+
+	      if (board_info->last_mail == NULL
+		  || strcmp(board_info->last_mail, response.mailto) != 0)
+		{
+		  if (board_info->last_mail != NULL)
+		    G_FREE(board_info->last_mail);
+		  board_info->last_mail = G_STRDUP(response.mailto);
+		}
+
+	      if (application->last_name == NULL
+		  || strcmp(application->last_name, response.name) != 0)
+		{
+		  if (application->last_name != NULL)
+		    G_FREE(application->last_name);
+		  application->last_name = G_STRDUP(response.name);
+		}
+
+	      if (application->last_mail == NULL
+		  || strcmp(application->last_mail, response.mailto) != 0)
+		{
+		  if (application->last_mail != NULL)
+		    G_FREE(application->last_mail);
+		  application->last_mail = G_STRDUP(response.mailto);
+		}
+	    }
+	}
+      else
+	{
+	  /* ʸʤϥ顼ˤʤ餷 */
+	  result = TRUE;
+	  response_id = GTK_RESPONSE_CANCEL;
+	}
+    }
+  else
+    result = TRUE;
+
+  if (result)
+    {
+      if (response_id == GTK_RESPONSE_OK)
+	refresh_threadlist_view(application, board);
+      gtk_widget_destroy(dialog);
+    }
+  else
+    ochusha_open_url(application,
+		     ochusha_bulletin_board_get_base_url(board),
+		     FALSE, TRUE);
+}
+
+
+static GtkWidget *
+create_new_thread_dialog(OchushaApplication *application,
+			 OchushaBulletinBoard *board)
+{
+  GtkWidget *new_thread_dialog;
+  GtkWidget *dialog_vbox;
+#if 0
+  GtkWidget *url_hbox;
+  GtkWidget *url_entry;
+#endif
+  GtkWidget *title_hbox;
+  GtkWidget *title_entry;
+  GtkWidget *board_label;
+  GtkWidget *editor;
+  ResponseEditor *response_editor;
+  BulletinBoardGUIInfo *board_info = ensure_bulletin_board_info(board,
+								application);
+  gboolean has_name = FALSE;
+  gboolean has_mail = FALSE;
+  gchar board_name_buffer[2048];
+
+  new_thread_dialog = gtk_dialog_new_with_buttons(_("Create a New Thread"),
+					 application->top_level,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_OK, GTK_RESPONSE_OK,
+					 NULL);
+  gtk_window_set_position(GTK_WINDOW(new_thread_dialog), GTK_WIN_POS_CENTER);
+  gtk_window_set_default_size(GTK_WINDOW(new_thread_dialog), -1, 250);
+
+  dialog_vbox = GTK_DIALOG(new_thread_dialog)->vbox;
+
+  snprintf(board_name_buffer, 2048, _("Create a New Thread on %s board"),
+	   ochusha_bulletin_board_get_name(board));
+  board_label = gtk_label_new(board_name_buffer);
+  gtk_label_set_justify(GTK_LABEL(board_label), GTK_JUSTIFY_LEFT);
+  gtk_widget_show(board_label);
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), board_label, FALSE, FALSE, 10);
+
+#if 0
+  url_hbox = gtk_hbox_new(FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(url_hbox), gtk_label_new("URL: "),
+		     FALSE, FALSE, 0);
+  url_entry = gtk_entry_new();
+  gtk_entry_set_text(GTK_ENTRY(url_entry),
+		     ochusha_bulletin_board_get_base_url(board));
+  gtk_editable_set_editable(GTK_EDITABLE(url_entry), FALSE);
+  GTK_WIDGET_UNSET_FLAGS(url_entry, GTK_CAN_FOCUS);
+  gtk_box_pack_start(GTK_BOX(url_hbox), url_entry, TRUE, TRUE, 0);
+  gtk_widget_show_all(url_hbox);
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), url_hbox, FALSE, FALSE, 0);
+#endif
+
+  title_hbox = gtk_hbox_new(FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(title_hbox), gtk_label_new(_("Title: ")),
+		     FALSE, FALSE, 0);
+  title_entry = gtk_entry_new();
+  gtk_editable_set_editable(GTK_EDITABLE(title_entry), TRUE);
+  GTK_WIDGET_SET_FLAGS(title_entry, GTK_CAN_FOCUS);
+  gtk_box_pack_start(GTK_BOX(title_hbox), title_entry, TRUE, TRUE, 0);
+  gtk_widget_show_all(title_hbox);
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), title_hbox, FALSE, FALSE, 0);
+
+  editor = response_editor_new();
+  response_editor = RESPONSE_EDITOR(editor);
+
+  if (board_info->last_name != NULL)
+    {
+      response_editor_add_name(response_editor, board_info->last_name);
+      if (!has_name)
+	{
+	  response_editor_set_name(response_editor, board_info->last_name);
+	  has_name = TRUE;
+	}
+    }
+
+  if (board_info->last_mail != NULL)
+    {
+      response_editor_add_mail(response_editor, board_info->last_mail);
+      if (!has_mail)
+	{
+	  response_editor_set_mail(response_editor, board_info->last_mail);
+	  has_mail = TRUE;
+	}
+    }
+
+  if (application->last_name != NULL)
+    {
+      response_editor_add_name(response_editor, application->last_name);
+      if (!has_name)
+	response_editor_set_name(response_editor, application->last_name);
+    }
+
+  if (application->last_mail != NULL)
+    {
+      response_editor_add_mail(response_editor, application->last_mail);
+      if (!has_mail)
+	response_editor_set_mail(response_editor, application->last_mail);
+    }
+
+  gtk_widget_show(editor);
+
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), editor, TRUE, TRUE, 0);
+
+  g_object_set_data(G_OBJECT(new_thread_dialog), "editor", editor);
+  g_object_set_data(G_OBJECT(new_thread_dialog), "title", title_entry);
+  g_object_set_data(G_OBJECT(new_thread_dialog), "board", board);
+
+  return new_thread_dialog;
+}
+
