@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.46 2003/11/22 19:17:16 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.49 2003/11/23 22:39:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -161,6 +161,7 @@ static guint title_popup_delay_id = 0;
 
 
 static GQuark board_info_id;
+static GQuark application_id;
 
 
 void
@@ -179,6 +180,7 @@ prepare_board_ui_initialization(OchushaApplication *application)
     }
 
   board_info_id = g_quark_from_static_string("BulletinBoardUI::BoardInfo");
+  application_id = g_quark_from_static_string("BulletinBoardUI::Application");
 }
 
 
@@ -483,10 +485,26 @@ customize_threadlist_view_contents(OchushaApplication *application,
 
 
 static void
-open_view_cb(GtkWidget *selector, gpointer item, gboolean in_tab,
-	     PanedNotebook *paned_notebook)
+open_thread_view_cb(GtkWidget *selector, OchushaBBSThread *thread,
+		    gboolean in_tab, gboolean with_browser,
+		    PanedNotebook *paned_notebook)
 {
-  paned_notebook_open_item_view(paned_notebook, item, in_tab);
+  if (!with_browser)
+    paned_notebook_open_item_view(paned_notebook, thread, in_tab);
+  else
+    {
+      OchushaApplication *application
+	= g_object_get_qdata(G_OBJECT(selector), application_id);
+      if (application != NULL)
+	ochusha_open_url(application,
+			 ochusha_bbs_thread_get_url_to_post_response(thread),
+			 in_tab, with_browser);
+#if 0	/* Թͽ */
+      else
+	fprintf(stderr, "open_thread_view_cb: %s\n",
+		ochusha_bbs_thread_get_url_to_post_response(thread));
+#endif
+    }
 }
 
 
@@ -528,6 +546,7 @@ open_bulletin_board(OchushaApplication *application,
       gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
 					  GTK_SHADOW_ETCHED_IN);
       view = threadlist_view_new();
+      g_object_set_qdata(G_OBJECT(view), application_id, application);
       customize_threadlist_view_contents(application, THREADLIST_VIEW(view));
 
       job = G_NEW0(WorkerJob, 1);
@@ -540,8 +559,8 @@ open_bulletin_board(OchushaApplication *application,
       paned_notebook
 	= paned_notebook_new_with_selector(application->threadlist_pane_style,
 					   scrolled_window);
-      g_signal_connect(G_OBJECT(view), "open_view",
-		       G_CALLBACK(open_view_cb), paned_notebook);
+      g_signal_connect(G_OBJECT(view), "open_thread_view",
+		       G_CALLBACK(open_thread_view_cb), paned_notebook);
       gtk_paned_set_position(GTK_PANED(paned_notebook),
 			     application->threadlist_height);
       paned_notebook_set_tab_shrinkable(PANED_NOTEBOOK(paned_notebook),
@@ -930,7 +949,7 @@ each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
     = (!args->application->config.offline && args->increment_ignored);
 
 #if DEBUG_GUI_MOST
-  gchar *title = convert_string(utf8_to_native, thread->title, -1);
+  gchar *title = convert_string(utf8_to_native, NULL, thread->title, -1);
   fprintf(stderr, "each_thread_cb: %s <%d>\n",
 	  title, thread->number_of_responses_on_server);
   G_FREE(title);
@@ -1353,7 +1372,6 @@ item_view_required_cb(PanedNotebook *paned_notebook,
 		      const gchar **title, GtkWidget **tab_label,
 		      OchushaApplication *application)
 {
-#if 1
   GtkWidget *thread_view;
   *tab_label = get_tab_label(thread->title);
 
@@ -1374,15 +1392,6 @@ item_view_required_cb(PanedNotebook *paned_notebook,
     *item_view = NULL;
 
   *title = thread->title;
-#else
-  *tab_label = get_tab_label(thread->title);
-
-  *item_view = open_bbs_thread(application, thread, ICON_LABEL(*tab_label));
-  if (*item_view != NULL)
-    gtk_widget_show(*item_view);
-
-  *title = thread->title;
-#endif
 }
 
 
@@ -1749,10 +1758,9 @@ write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
   else
     result = TRUE;
 
-  gtk_widget_destroy(write_dialog);
-
   if (result)
     {
+      gtk_widget_destroy(write_dialog);
       if (response_id == GTK_RESPONSE_OK)
 	{
 	  GtkWidget *notebook = paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), thread->board);
@@ -2078,7 +2086,7 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
   gtk_box_pack_start(GTK_BOX(dialog_vbox), url_hbox, FALSE, FALSE, 0);
 
 
-  editor = response_editor_new(thread);
+  editor = response_editor_new();
   response_editor = RESPONSE_EDITOR(editor);
 
   if (thread_info->last_name != NULL)
