@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.26 2003/11/22 19:17:16 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.27 2003/11/23 22:04:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -988,7 +988,8 @@ configure_application(OchushaApplication *application)
     application->popup_title_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
 
   if (application->web_browser_template == NULL)
-    application->web_browser_template = g_strdup("mozilla -raise -remote \"openURL(%s,new-window)\"");
+    application->web_browser_template
+      = g_strdup(OCHUSHA_DEFAULT_WEB_BROWSER_TEMPLATE);
 }
 
 
