@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.21 2003/11/22 19:17:16 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.22 2003/11/23 22:04:09 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -70,6 +70,8 @@
 #define OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE				80
 #define OCHUSHA_DEFAULT_BOARD_TAB_ENABLE_TOOLTIPS			FALSE
 
+#define OCHUSHA_DEFAULT_THREADLIST_FILTER_RULE			"FhDrSNsa"
+
 #define OCHUSHA_DEFAULT_THREAD_TAB_SHRINKABLE				TRUE
 #define OCHUSHA_DEFAULT_THREAD_TAB_MINIMUM_SIZE				80
 #define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS			TRUE
@@ -92,6 +94,7 @@
 
 #define OCHUSHA_DEFAULT_SHOW_MAILTO_MODE	THREAD_VIEW_MAILTO_MODE_DEFAULT
 
+#define OCHUSHA_DEFAULT_WEB_BROWSER_TEMPLATE	"mozilla -raise -remote \"openURL(%s,new-window)\""
 
 #define OCHUSHA_GTKRC				"ochusha-gtkrc"
 
