@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.10 2003/11/07 15:52:40 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.11 2003/11/23 17:07:26 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -105,8 +105,9 @@ struct _ThreadlistViewClass
 {
   GtkTreeViewClass parent_class;
 
-  void (*open_view)(ThreadlistView *threadlist_view, OchushaBBSThread *thread,
-		    gboolean in_tab);
+  void (*open_thread_view)(ThreadlistView *threadlist_view,
+			   OchushaBBSThread *thread,
+			   gboolean in_tab, gboolean with_browser);
 
   void (*thread_mouse_over)(ThreadlistView *threadlist_view,
 			    OchushaBBSThread *thread);
