@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.4 2003/11/20 00:48:25 fuyu Exp $
+ * $Id: ochusha.h,v 1.5 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -128,6 +128,33 @@ char *ochusha_utils_get_attribute_string(GHashTable *hash_table,
 					 const char *attr_name);
 
 
+typedef struct _OchushaBBSThread OchushaBBSThread;
+typedef struct _OchushaBBSThreadClass OchushaBBSThreadClass;
+
+typedef gboolean EachThreadCallback(OchushaBBSThread *thread,
+				    gpointer user_data);
+typedef struct _OchushaBBSResponse OchushaBBSResponse;
+typedef gboolean StartThreadCallback(OchushaBBSThread *thread,
+				     const char *title,
+				     gpointer callback_data);
+typedef gboolean EachResponseCallback(OchushaBBSThread *thread, int number,
+				      const OchushaBBSResponse *response,
+				      gpointer callback_data);
+typedef gboolean BrokenResponseCallback(OchushaBBSThread *thread, int number,
+					gpointer callback_data);
+typedef gboolean EndThreadCallback(OchushaBBSThread *thread, gboolean finished,
+				   gpointer callback_data);
+
+
+struct _OchushaBBSResponse
+{
+  const gchar *name;
+  const gchar *mailto;
+  const gchar *date_id;
+  const gchar *content;
+};
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
