@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.12 2003/11/18 21:02:05 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.13 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -52,17 +52,10 @@ extern "C" {
 #define OCHUSHA_BBS_THREAD_GET_CLASS(obj) 	(G_TYPE_INSTANCE_GET_CLASS((obj), OCHUSHA_TYPE_BBS_THREAD, OchushaBBSThreadClass))
 
 
-typedef struct _OchushaBBSResponse OchushaBBSResponse;
-typedef gboolean StartThreadCallback(OchushaBBSThread *thread,
-				     const char *title,
-				     gpointer callback_data);
-typedef gboolean EachResponseCallback(OchushaBBSThread *thread, int number,
-				      const OchushaBBSResponse *response,
-				      gpointer callback_data);
-typedef gboolean BrokenResponseCallback(OchushaBBSThread *thread, int number,
-					gpointer callback_data);
-typedef gboolean EndThreadCallback(OchushaBBSThread *thread, gboolean finished,
-				   gpointer callback_data);
+#if 0	/* 餷ġ */
+typedef struct _OchushaBBSThread OchushaBBSThread;
+typedef struct _OchushaBBSThreadClass OchushaBBSThreadClass;
+#endif
 
 
 struct _OchushaBBSThread
@@ -133,15 +126,6 @@ struct _OchushaBBSThreadClass
 };
 
 
-struct _OchushaBBSResponse
-{
-  const gchar *name;
-  const gchar *mailto;
-  const gchar *date_id;
-  const gchar *content;
-};
-
-
 typedef enum
 {
   OCHUSHA_BBS_THREAD_DAT_DROPPED = 1 << 0,
