@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.15 2003/11/22 08:46:55 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.19 2003/11/23 22:39:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,11 +40,6 @@
 #include <glib-object.h>
 #include <glib.h>
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-
 #if ENABLE_REGEXP
 # if HAVE_ONIGURUMA
 #  if HAVE_ONIG_ONIGPOSIX_H
@@ -68,6 +63,12 @@
 # endif
 #endif
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include <unistd.h>
+
 
 static OchushaBulletinBoardClass *parent_class = NULL;
 
@@ -113,6 +114,13 @@ static const char *ochusha_board_2ch_get_response_character_encoding(
 						OchushaBulletinBoard *board);
 static iconv_helper *ochusha_board_2ch_get_response_iconv_helper(
 						OchushaBulletinBoard *board);
+static gboolean ochusha_board_2ch_is_new_thread_supported(
+						OchushaBulletinBoard *board);
+static gboolean ochusha_board_2ch_create_new_thread(
+					OchushaBulletinBoard *board,
+					OchushaConfig *config,
+					const gchar *title,
+					const OchushaBBSResponse *response);
 
 GType
 ochusha_board_2ch_get_type(void)
@@ -168,6 +176,11 @@ ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
   b_class->get_response_iconv_helper
     = ochusha_board_2ch_get_response_iconv_helper;
 
+  b_class->new_thread_supported
+    = ochusha_board_2ch_is_new_thread_supported;
+  b_class->create_new_thread
+    = ochusha_board_2ch_create_new_thread;
+
   klass->get_read_cgi_url = NULL;
 }
 
@@ -179,6 +192,7 @@ ochusha_board_2ch_init(OchushaBoard2ch *board)
 
   board->read_cgi_url = NULL;
   board->last_modified = NULL;
+  board->date = NULL;
   board->cookie = NULL;
 }
 
@@ -200,6 +214,12 @@ ochusha_board_2ch_finalize(GObject *object)
       board_2ch->last_modified = NULL;
     }
 
+  if (board_2ch->date != NULL)
+    {
+      G_FREE(board_2ch->date);
+      board_2ch->date = NULL;
+    }
+
   if (board_2ch->cookie != NULL)
     {
       G_FREE(board_2ch->cookie);
@@ -473,6 +493,175 @@ ochusha_board_2ch_get_response_iconv_helper(OchushaBulletinBoard *board)
 }
 
 
+static gboolean
+ochusha_board_2ch_is_new_thread_supported(OchushaBulletinBoard *board)
+{
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board), FALSE);
+
+  switch (board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+      return TRUE;
+
+    default:
+      return FALSE;
+    }
+}
+
+
+static gboolean
+ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
+				    OchushaConfig *config,
+				    const gchar *title_utf8,
+				    const OchushaBBSResponse *response)
+{
+  OchushaBoard2ch *board_2ch;
+  char *tmp_string = NULL;
+  char *title = NULL;
+  char *from = NULL;
+  char *mail = NULL;
+  char *message = NULL;
+  const char *bbs;
+  char *query = NULL;
+  time_t time;
+  iconv_t converter;
+  OchushaUtils2chPostResult post_result;
+
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board), FALSE);
+  g_return_val_if_fail(title_utf8 != NULL && *title_utf8 != '\0', FALSE);
+  g_return_val_if_fail(response->name != NULL, FALSE);
+  g_return_val_if_fail(response->mailto != NULL, FALSE);
+  g_return_val_if_fail(response->content != NULL, FALSE);
+
+  switch (board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+      break;
+
+      /* case OCHUSHA_BBS_TYPE_MACHIBBS: */
+    default:
+      return FALSE;	/* ̤ݡ */
+    }
+
+  converter = iconv_open(ochusha_bulletin_board_get_response_character_encoding(board), "UTF-8");
+  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
+
+  board_2ch = OCHUSHA_BOARD_2CH(board);
+
+  tmp_string = convert_string(converter, NULL, title_utf8, -1);
+  title = ochusha_utils_url_encode_string(tmp_string);
+  if (title == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+
+  tmp_string = convert_string(converter, NULL, response->name, -1);
+  from = ochusha_utils_url_encode_string(tmp_string);
+  if (from == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+
+  tmp_string = convert_string(converter, NULL, response->mailto, -1);
+  mail = ochusha_utils_url_encode_string(tmp_string);
+  if (mail == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+
+  tmp_string = convert_string(converter, NULL, response->content, -1);
+  message = ochusha_utils_url_encode_string(tmp_string);
+  if (message == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+  tmp_string = NULL;
+
+  bbs = ochusha_bulletin_board_get_id(board);
+
+  if (board_2ch->date != NULL)
+    time = ochusha_utils_get_utc_time(board_2ch->date);
+  else
+    {
+#if DEBUG_POST
+      fprintf(stderr, "board_2ch->date == NULL!\n");
+#endif
+      time = ochusha_utils_get_utc_time(board_2ch->last_modified);
+    }
+
+  if (time == -1)
+    goto error_exit;
+
+  /* XXX: ϡɥǥ󥰤㤦ΤϤäʤġġ*/
+  switch (board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+      query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&subject=%s&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&time=%ld", title, from, mail, message, bbs, time);
+      break;
+
+#if 0
+    case OCHUSHA_BBS_TYPE_MACHIBBS:
+      query = g_strdup_printf("submit=%%90%%56%%8B%%4B%%83%%58%%83%%8C%%83%%62%%83%%68%%8D%%EC%%90%%AC&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld", from, mail, message, bbs, key, time);
+      break;
+#endif
+    default:
+      goto error_exit;
+    }
+
+  post_result = ochusha_utils_2ch_try_post(board, query);
+  if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
+    {
+      sleep(10);
+      post_result = ochusha_utils_2ch_try_post(board, query);
+    }
+
+#if 0
+  if (post_result == OCHUSHA_UTILS_2CH_POST_MOCHITSUKE)
+    {
+      /* XXX: äݤΤȤͭʤΤ֡ */
+      sleep(30);
+      post_result = ochusha_utils_2ch_try_post(thread, query);
+    }
+#endif
+  if (post_result != OCHUSHA_UTILS_2CH_POST_SUCCESS)
+    goto error_exit;
+
+  /* ｪλ */
+  if (tmp_string != NULL)
+    G_FREE(tmp_string);
+  if (title != NULL)
+    G_FREE(title);
+  if (from != NULL)
+    G_FREE(from);
+  if (mail != NULL)
+    G_FREE(mail);
+  if (message != NULL)
+    G_FREE(message);
+  if (query != NULL)
+    G_FREE(query);
+  iconv_close(converter);
+
+  return TRUE;
+
+ error_exit:
+#if DEBUG_POST
+  fprintf(stderr, "Error happen\n");
+#endif
+
+  if (tmp_string != NULL)
+    G_FREE(tmp_string);
+  if (title != NULL)
+    G_FREE(title);
+  if (from != NULL)
+    G_FREE(from);
+  if (mail != NULL)
+    G_FREE(mail);
+  if (message != NULL)
+    G_FREE(message);
+  if (query != NULL)
+    G_FREE(query);
+  iconv_close(converter);
+
+  return FALSE;
+}
+
+
 OchushaBulletinBoard *
 ochusha_board_2ch_new(const gchar *name, const char *base_url)
 {
@@ -609,16 +798,43 @@ unmark_alive(gpointer data, gpointer user_data)
 }
 
 
+typedef struct _CollectDroppedThreadArgs
+{
+  GSList *thread_list;
+  EachThreadCallback *each_thread_cb;
+  gpointer callback_data;
+} CollectDroppedThreadArgs;
+
+
 static void
 collect_dropped_thread(gpointer data, gpointer user_data)
 {
+  CollectDroppedThreadArgs *args = (CollectDroppedThreadArgs *)user_data;
   OchushaThread2ch *thread_2ch = OCHUSHA_THREAD_2CH(data);
+
   if (!thread_2ch->alive)
     {
-      OchushaBBSThread *thread = (OchushaBBSThread *)thread_2ch;
       /* threadDATäݤ*/
-      thread->board->dropped_list
-	= g_slist_append(thread->board->dropped_list, thread);
+      OchushaBBSThread *thread = (OchushaBBSThread *)thread_2ch;
+      if (thread->number_of_responses_read > 0)
+	{
+	  if (g_slist_find(args->thread_list, thread) == NULL)
+	    {
+	      thread->flags |= OCHUSHA_BBS_THREAD_DAT_DROPPED;
+	      thread->number_of_responses_on_server = 0;
+	      args->thread_list = g_slist_append(args->thread_list, thread);
+	      if (args->each_thread_cb != NULL)
+		if (!(*args->each_thread_cb)(thread, args->callback_data))
+		  args->each_thread_cb = FALSE;
+#if 0	/* debug */
+	      fprintf(stderr, "Resurrect DAT dropped thread: %s\n",
+		      ochusha_bbs_thread_get_url(thread));
+#endif
+	    }
+	}
+      else
+	thread->board->dropped_list
+	  = g_slist_append(thread->board->dropped_list, thread);
     }
   else
     g_object_unref(G_OBJECT(data));	/* Ƥ륹thread_list
@@ -651,9 +867,9 @@ undo_thread_ref(gpointer data, gpointer user_data)
  */
 static gboolean
 refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
-				     OchushaAsyncBuffer *buffer,
-				     EachThreadCallback *each_thread_cb,
-				     gpointer callback_data)
+				  OchushaAsyncBuffer *buffer,
+				  EachThreadCallback *each_thread_cb,
+				  gpointer callback_data)
 {
   char default_buffer[PATH_MAX];
   char scan_buffer[5];
@@ -877,22 +1093,39 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
   }
   ochusha_async_buffer_unlock(buffer);
 
-  if (result && status->last_modified != NULL)
+  if (result)
     {
       OchushaBoard2ch *board_2ch = OCHUSHA_BOARD_2CH(board);
 
-      if (board_2ch->last_modified != NULL)
-	G_FREE(board_2ch->last_modified);
-      board_2ch->last_modified = G_STRDUP(status->last_modified);
+      if (status->last_modified != NULL)
+	{
+	  if (board_2ch->last_modified != NULL)
+	    G_FREE(board_2ch->last_modified);
+	  board_2ch->last_modified = G_STRDUP(status->last_modified);
+	}
+
+      if (status->date != NULL)
+	{
+	  if (board_2ch->date != NULL)
+	    G_FREE(board_2ch->date);
+	  board_2ch->date = G_STRDUP(status->date);
+	}
     }
 
   ochusha_async_buffer_active_unref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist");
 
   if (result)
     {
-      g_slist_foreach(old_thread_list, collect_dropped_thread, NULL);
+      CollectDroppedThreadArgs args =
+	{
+	  thread_list,
+	  each_thread_cb,
+	  callback_data
+	};
+
+      g_slist_foreach(old_thread_list, collect_dropped_thread, &args);
+      board->thread_list = args.thread_list;
       g_slist_free(old_thread_list);
-      board->thread_list = thread_list;
     }
   else
     {
@@ -1084,22 +1317,39 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
   }
   ochusha_async_buffer_unlock(buffer);
 
-  if (result && status->last_modified != NULL)
+  if (result)
     {
       OchushaBoard2ch *board_2ch = OCHUSHA_BOARD_2CH(board);
 
-      if (board_2ch->last_modified != NULL)
-	G_FREE(board_2ch->last_modified);
-      board_2ch->last_modified = G_STRDUP(status->last_modified);
+      if (status->last_modified != NULL)
+	{
+	  if (board_2ch->last_modified != NULL)
+	    G_FREE(board_2ch->last_modified);
+	  board_2ch->last_modified = G_STRDUP(status->last_modified);
+	}
+
+      if (status->date != NULL)
+	{
+	  if (board_2ch->date != NULL)
+	    G_FREE(board_2ch->date);
+	  board_2ch->date = G_STRDUP(status->date);
+	}
     }
 
   ochusha_async_buffer_active_unref(buffer, "ochusha_board_2ch.c: ochusha_board_2ch_refresh_threadlist");
 
   if (result)
     {
-      g_slist_foreach(old_thread_list, collect_dropped_thread, NULL);
+      CollectDroppedThreadArgs args =
+	{
+	  thread_list,
+	  each_thread_cb,
+	  callback_data
+	};
+
+      g_slist_foreach(old_thread_list, collect_dropped_thread, &args);
+      board->thread_list = args.thread_list;
       g_slist_free(old_thread_list);
-      board->thread_list = thread_list;
     }
   else
     {
