@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.14 2003/11/21 21:30:03 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.16 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -199,6 +199,9 @@ ochusha_bulletin_board_class_init(OchushaBulletinBoardClass *klass)
   klass->lookup_thread_by_url = NULL;
   klass->get_threadlist_source = NULL;
   klass->refresh_threadlist = NULL;
+  klass->preview_new_thread = NULL;
+  klass->new_thread_supported = NULL;
+  klass->create_new_thread = NULL;
 }
 
 
@@ -599,6 +602,76 @@ ochusha_bulletin_board_get_response_iconv_helper(OchushaBulletinBoard *board)
 }
 
 
+gboolean
+ochusha_bulletin_board_is_new_thread_preview_supported(
+						OchushaBulletinBoard *board)
+{
+  OchushaBulletinBoardClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board), FALSE);
+
+  klass = OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+  return klass->preview_new_thread != NULL;
+}
+
+
+gboolean
+ochusha_bulletin_board_preview_new_thread(OchushaBulletinBoard *board,
+					  const gchar *title,
+					  const OchushaBBSResponse *response,
+					  StartThreadCallback *start_cb,
+					  EachResponseCallback *response_cb,
+					  EndThreadCallback *end_cb,
+					  gpointer callback_data)
+{
+  OchushaBulletinBoardClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board)
+		       && title != NULL && response != NULL, FALSE);
+
+  klass = OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+
+  return (*klass->preview_new_thread)(board, title, response,
+				      start_cb, response_cb, end_cb,
+				      callback_data);
+}
+
+
+gboolean
+ochusha_bulletin_board_is_new_thread_supported(OchushaBulletinBoard *board)
+{
+  OchushaBulletinBoardClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board), FALSE);
+
+  klass = OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+  if (klass->new_thread_supported != NULL)
+    return (*klass->new_thread_supported)(board);
+
+  return FALSE;
+}
+
+
+gboolean
+ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
+					 OchushaConfig *config,
+					 const gchar *title,
+					 const OchushaBBSResponse *response)
+{
+  OchushaBulletinBoardClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BULLETIN_BOARD(board)
+		       && config != NULL && title != NULL && response != NULL,
+		       FALSE);
+
+  klass = OCHUSHA_BULLETIN_BOARD_GET_CLASS(board);
+
+  g_return_val_if_fail(klass->create_new_thread != NULL, FALSE);
+
+  return (*klass->create_new_thread)(board, config, title, response);
+}
+
+
 /*
  * boardlist.xmlϢ
  */
@@ -930,14 +1003,19 @@ endElementHandler(void *context, const xmlChar *name)
 			= ochusha_bulletin_board_bbs_thread_new(board,
 								thread_id,
 								title);
-		      g_signal_emit_by_name(G_OBJECT(thread),
-					    "read_threadlist_element",
-					    thread_attrs);
-		      g_signal_emit(G_OBJECT(board),
-				    bulletin_board_signals[THREADLIST_READ_THREAD_ELEMENT_SIGNAL],
-				    0,
-				    thread,
-				    thread_attrs);
+		      if (thread != NULL)
+			{
+			  g_signal_emit_by_name(G_OBJECT(thread),
+						"read_threadlist_element",
+						thread_attrs);
+			  g_signal_emit(G_OBJECT(board),
+					bulletin_board_signals[THREADLIST_READ_THREAD_ELEMENT_SIGNAL],
+					0,
+					thread,
+					thread_attrs);
+			  board->thread_list
+			    = g_slist_append(board->thread_list, thread);
+			}
 		    }
 		}
 	      if (tmp_id != NULL)
