@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.8 2003/11/21 21:30:03 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.9 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -52,11 +52,6 @@ extern "C" {
 
 typedef struct _OchushaBulletinBoard OchushaBulletinBoard;
 typedef struct _OchushaBulletinBoardClass OchushaBulletinBoardClass;
-typedef struct _OchushaBBSThread OchushaBBSThread;
-typedef struct _OchushaBBSThreadClass OchushaBBSThreadClass;
-typedef gboolean EachThreadCallback(OchushaBBSThread *thread,
-				    gpointer user_data);
-
 
 typedef enum
 {
@@ -133,6 +128,18 @@ struct _OchushaBulletinBoardClass
 
   const char *(*get_response_character_encoding)(OchushaBulletinBoard *board);
   iconv_helper *(*get_response_iconv_helper)(OchushaBulletinBoard *board);
+
+  gboolean (*preview_new_thread)(OchushaBulletinBoard *board,
+				 const gchar *title,
+				 const OchushaBBSResponse *response,
+				 StartThreadCallback *start_cb,
+				 EachResponseCallback *response_cb,
+				 EndThreadCallback *end_cb,
+				 gpointer callback_data);
+  gboolean (*new_thread_supported)(OchushaBulletinBoard *board);
+  gboolean (*create_new_thread)(OchushaBulletinBoard *board,
+				OchushaConfig *config, const gchar *title,
+				const OchushaBBSResponse *response);
 };
 
 
@@ -179,6 +186,22 @@ const char *ochusha_bulletin_board_get_response_character_encoding(
 iconv_helper *ochusha_bulletin_board_get_response_iconv_helper(
 						OchushaBulletinBoard *board);
 
+gboolean ochusha_bulletin_board_is_new_thread_preview_supported(
+						OchushaBulletinBoard *board);
+gboolean ochusha_bulletin_board_preview_new_thread(OchushaBulletinBoard *board,
+					const gchar *title,
+					const OchushaBBSResponse *response,
+					StartThreadCallback *start_cb,
+					EachResponseCallback *response_cb,
+					EndThreadCallback *end_cb,
+					gpointer callback_data);
+gboolean ochusha_bulletin_board_is_new_thread_supported(
+						OchushaBulletinBoard *board);
+gboolean ochusha_bulletin_board_create_new_thread(OchushaBulletinBoard *board,
+					OchushaConfig *config,
+					const gchar *title,
+					const OchushaBBSResponse *response);
+
 gboolean ochusha_bulletin_board_read_threadlist_xml(
 					OchushaBulletinBoard *board,
 					OchushaConfig *config);
