@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.24 2003/11/21 21:30:03 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.26 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -492,6 +492,9 @@ ochusha_thread_2ch_get_responses_source(OchushaBBSThread *thread,
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
 
+  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED)
+    mode = OCHUSHA_NETWORK_BROKER_CACHE_ONLY;
+
   switch (thread->board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_2CH:
@@ -1099,7 +1102,15 @@ ochusha_thread_2ch_post_supported(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), FALSE);
   g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(thread->board), FALSE);
 
-  return (thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH);
+  switch (thread->board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_MACHIBBS:
+      return TRUE;
+
+    default:
+      return FALSE;
+    }
 }
 
 
@@ -1127,8 +1138,15 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   g_return_val_if_fail(response->mailto != NULL, FALSE);
   g_return_val_if_fail(response->content != NULL, FALSE);
 
-  if (thread->board->bbs_type != OCHUSHA_BBS_TYPE_2CH)
-    return FALSE;	/* ̤ݡ */
+  switch (thread->board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+    case OCHUSHA_BBS_TYPE_MACHIBBS:
+      break;
+
+    default:
+      return FALSE;	/* ̤ݡ */
+    }
 
   converter = iconv_open(ochusha_bulletin_board_get_response_character_encoding(thread->board), "UTF-8");
   g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
@@ -1172,13 +1190,25 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
     goto error_exit;
 
   /* XXX: ϡɥǥ󥰤㤦ΤϤäʤġġ*/
-  query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
+  switch (thread->board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+      query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
+      break;
 
-  post_result = ochusha_utils_2ch_try_post(thread, query);
+    case OCHUSHA_BBS_TYPE_MACHIBBS:
+      query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&NAME=%s&MAIL=%s&MESSAGE=%s&BBS=%s&KEY=%s&TIME=%ld", from, mail, message, bbs, key, time);
+      break;
+
+    default:
+      goto error_exit;
+    }
+
+  post_result = ochusha_utils_2ch_try_post(thread->board, query);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       sleep(10);
-      post_result = ochusha_utils_2ch_try_post(thread, query);
+      post_result = ochusha_utils_2ch_try_post(thread->board, query);
     }
 
 #if 0
@@ -1186,7 +1216,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(thread, query);
+      post_result = ochusha_utils_2ch_try_post(thread->board, query);
     }
 #endif
 
