@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.13 2003/11/22 16:57:50 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.16 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #include "config.h"
@@ -122,7 +122,7 @@ parse_thread_path(char *path, char **thread_id_p,
       if (thread_id_p != NULL && *path != '\0')
 	thread_id = G_STRDUP(path);
       else
-	thread_id = path;
+	thread_id = NULL;
     }
 
   if (thread_id_p != NULL)
@@ -593,7 +593,7 @@ ochusha_utils_2ch_check_url(const char *url, char **board_url_p,
       if (slash_pos != NULL)
 	{
 	  slash_pos[0] = '\0';
-	  snprintf(board_url, PATH_MAX, "http://%s%s", server, abs_path);
+	  snprintf(board_url, PATH_MAX, "http://%s%s/", server, abs_path);
 	  board_id = G_STRDUP(abs_path + 1);
 	  slash_pos[0] = '/';
 	  parse_thread_path(slash_pos + 1, &thread_id, &from, &to);
@@ -988,31 +988,55 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 
 
 OchushaUtils2chPostResult
-ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
+ochusha_utils_2ch_try_post(OchushaBulletinBoard *board, const char *message)
 {
-  char uri[PATH_MAX];
+  char url[PATH_MAX];
   ghttp_request *request;
   const char *cookie;
   const char *new_cookie = NULL;
   int status_code;
   OchushaBoard2ch *board_2ch;
   gboolean post_error = FALSE;
+  int result;
 
-  g_return_val_if_fail(g_snprintf(uri, PATH_MAX, "http://%s/test/bbs.cgi",
-				  thread->board->server) < PATH_MAX,
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(board),
 		       OCHUSHA_UTILS_2CH_POST_FAILURE);
-  g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread),
-		       OCHUSHA_UTILS_2CH_POST_FAILURE);
-  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(thread->board),
-		       OCHUSHA_UTILS_2CH_POST_FAILURE);
-  board_2ch = OCHUSHA_BOARD_2CH(thread->board);
+
+  switch (board->bbs_type)
+    {
+    case OCHUSHA_BBS_TYPE_2CH:
+      result = snprintf(url, PATH_MAX, "http://%s/test/bbs.cgi",
+			ochusha_bulletin_board_get_server(board));
+      break;
+
+    case OCHUSHA_BBS_TYPE_MACHIBBS:
+      result = snprintf(url, PATH_MAX, "http://%s/bbs/write.cgi",
+			ochusha_bulletin_board_get_server(board));
+      break;
+
+    case OCHUSHA_BBS_TYPE_JBBS_SHITARABA:
+      result = snprintf(url, PATH_MAX, "http://%s/bbs/write.cgi",
+			ochusha_bulletin_board_get_server(board));
+      break;
+
+    default:
+      return OCHUSHA_UTILS_2CH_POST_FAILURE;
+    }
+  g_return_val_if_fail(result < PATH_MAX, OCHUSHA_UTILS_2CH_POST_FAILURE);
+
+#if DEBUG_POST_MOST
+  fprintf(stderr, "url: %s\n", url);
+#endif
+
+  board_2ch = OCHUSHA_BOARD_2CH(board);
 
   request = ghttp_request_new();
 
-  ghttp_set_uri(request, uri);
+  ghttp_set_uri(request, url);
   ghttp_set_type(request, ghttp_type_post);
 
-  ghttp_set_header(request, http_hdr_Host, thread->board->server);
+  ghttp_set_header(request, http_hdr_Host,
+		   ochusha_bulletin_board_get_server(board));
   ghttp_set_header(request, http_hdr_User_Agent, OCHUSHA_USER_AGENT);
 
   /* ɬפʤΤ */
@@ -1021,9 +1045,9 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
   ghttp_set_header(request, http_hdr_Accept_Charset, "EUC-JP,utf-8;q=0.66,*;q=0.66");
   ghttp_set_header(request, http_hdr_Connection, "close");
   ghttp_set_header(request, http_hdr_Referrer,
-		   ochusha_bbs_thread_get_url_to_post_response(thread));
+		   ochusha_bulletin_board_get_base_url(board));
   ghttp_set_header(request, "Referer",
-		   ochusha_bbs_thread_get_url_to_post_response(thread));
+		   ochusha_bulletin_board_get_base_url(board));
 
   cookie = ochusha_board_2ch_get_cookie(board_2ch);
   if (cookie != NULL)
@@ -1057,12 +1081,11 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
       int len = ghttp_get_body_len(request);
       const char *x_2ch = g_strstr_len(body, len, "2ch_X:");
 #if DEBUG_POST_MOST
-      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
-				    NULL, NULL, NULL);
+      char *tmp_body = g_strndup(body, len);
       fprintf(stderr, "Set-Cookie: %s\n",
 	      ghttp_get_header(request, http_hdr_Set_Cookie));
-      fprintf(stderr, "Result-Body: %s\n", native_body);
-      g_free(native_body);
+      fprintf(stderr, "Result-Body: %s\n", tmp_body);
+      g_free(tmp_body);
 #endif
 
       if (x_2ch != NULL)
@@ -1085,12 +1108,11 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
 	  else
 	    {
 #if DEBUG_POST
-	      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
-					    NULL, NULL, NULL);
+	      char *tmp_body = g_strndup(body, len);
 	      fprintf(stderr, "Set-Cookie: %s\n",
 		      ghttp_get_header(request, http_hdr_Set_Cookie));
-	      fprintf(stderr, "Result-Body: %s\n", native_body);
-	      g_free(native_body);
+	      fprintf(stderr, "Result-Body: %s\n", tmp_body);
+	      g_free(tmp_body);
 #endif
 	      post_error = TRUE;
 	    }
@@ -1101,13 +1123,12 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
     {
       const char *body = ghttp_get_body(request);
       int len = ghttp_get_body_len(request);
-      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
-				    NULL, NULL, NULL);
+      char *tmp_body = g_strndup(body, len);
       fprintf(stderr, "status_code = %d\n", status_code);
       fprintf(stderr, "Set-Cookie: %s\n",
 	      ghttp_get_header(request, http_hdr_Set_Cookie));
-      fprintf(stderr, "Result-Body: %s\n", native_body);
-      g_free(native_body);
+      fprintf(stderr, "Result-Body: %s\n", tmp_body);
+      g_free(tmp_body);
     }
 #endif
 
