@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.h,v 1.4 2003/11/21 21:30:03 fuyu Exp $
+ * $Id: ochusha_utils_2ch.h,v 1.5 2003/11/23 21:13:44 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UTILS_2CH_H_
@@ -73,8 +73,9 @@ typedef enum
 } OchushaUtils2chPostResult;
 
 
-OchushaUtils2chPostResult ochusha_utils_2ch_try_post(OchushaBBSThread *thread,
-						     const char *message);
+OchushaUtils2chPostResult ochusha_utils_2ch_try_post(
+						OchushaBulletinBoard *board,
+						const char *message);
 
 
 #ifdef __cplusplus
